@@ -10,13 +10,11 @@
 path <- paste(find.package("TDMR"), "demo02sonar",sep="/"); 
 #path <- paste("../inst", "demo02sonar",sep="/"); 
 
-oldwd <- getwd(); setwd(path);
-envT <- tdmEnvTLoad("demo03.RData");
-source("main_sonar.r");    # defines readTrnSonar
-source("sonar_06.apd")     # opts (sets opts$READ.TrnFn = readTrnSonar)
+envT <- tdmEnvTLoad("demo03.RData",path);
+source(paste(path,"main_sonar.r",sep="/"));    # defines readTrnSonar
+opts$READ.TrnFn = readTrnSonar
 opts$READ.NROW=-1;
-dataObj <- tdmSplitTestData(opts,envT$tdm); # read data, needs readTrnSonar  
+dataObj <- tdmReadAndSplit(opts,envT$tdm); # read data, needs readTrnSonar  
 newdata <- dataObj$dset[1:50,];
 z=predict(envT,newdata);
 print(z);
-setwd(oldwd); 
