@@ -1,5 +1,5 @@
 opts= tdmOptsDefaultsSet();
 tdm = list(umode="RSUB",runList="");
 data(iris);
-dataObj=tdmSplitTestData(opts,tdm,dset=iris);
+dataObj=tdmReadAndSplit(opts,tdm,dset=iris);
 print(dataObj)
